<h1 align="center">
  <a href="https://github.com/ju-djangun/cyes">
    <img src="https://user-images.githubusercontent.com/104500082/183290529-92a8b30e-4766-42df-957e-cb3d247a5f5f.svg" alt="Logo" height="300">
  </a>
</h1>

<div align="center">
  Cyes - C without {;}&nbsp;&nbsp;&nbsp; :hammer:
  <br />
  <br />
  <br />
  <a href="https://github.com/ju-djangun/cyes/issues/new?assignees=&labels=bug&template=01_BUG_REPORT.md&title=bug%3A+">Report a Bug</a>
  ·
  <a href="https://github.com/ju-djangun/cyes/issues/new?assignees=&labels=enhancement&template=02_FEATURE_REQUEST.md&title=feat%3A+">Request a Feature</a>
  .
  <a href="https://github.com/ju-djangun/cyes/issues/new?assignees=&labels=question&template=04_SUPPORT_QUESTION.md&title=support%3A+">Ask a Question</a>
</div>

<!-- shields here -->
<div align="center">
  <br />

  [![Project license](https://img.shields.io/github/license/ju-djangun/cyes.svg?style=flat-square)](LICENSE)
</div>

<details open="open">
<summary>Table of Contents</summary>

- [About](#about)
  - [Built With](#built-with)
- [Getting started](#getting-started)
  - [Prerequisites](#prerequisites)
- [Motivation](#motivation)
- [FAQ](#faq)
- [Contributing](#contributing)
- [License](#license)



</details>

----



## About

'cyes' is the transcompiler for Pythonistas who should code with C-like language(C/C++/C#...). 

It is simple, idiot CLI tool that auto semicolons&braces inserting by python-like 4-spacing indent and colons.

For this project, you can use both 'C-yes' and 'cy-es' depending on your preference. 

<br />
<br />

'cyes'는 C-like 프로그래밍 언어(C/C++/C#...)를 써야 하는 파이썬 개발자를 위한 트랜스파일러입니다.

간단하고 멍청하게 파이썬처럼 4개 공백문자와 쌍점으로 세미콜론과 중괄호를 자동 삽입하는 CLI 툴입니다.

취향껏 'C-yes(씨-예스)'나 'cy-es(싸이-스)'로 부르시면 됩니다.


### Built With

- python3.6+
- [typer](https://github.com/tiangolo/typer)
- [anytree](https://github.com/c0fec0de/anytree)
- [poetry](https://python-poetry.org/)
- [amazing-github-template](https://github.com/dec0dOS/amazing-github-template)


## Getting started

### Prerequisites

> Python 3.8 or higher


## Motivation

1. studying transpiler
2. My little finger is more important than C language tradition.

<br />
<br />

1. 트랜스파일러(컴파일러 및 형식 언어) 공부를 위한 토이 프로젝트
2. 새끼손가락을 아껴 사용합시다.


## FAQ
## Contributing

Thanks for taking the time to contribute.

<br />
<br />

기여에 관심을 가져주셔서 감사합니다.




## License

This project is licensed under the **MIT license**.

See [LICENSE](LICENSE) for more information.

<br />
<br />

이 프로젝트는 MIT 라이선스를 따릅니다.

[LICENSE](LICENSE) 파일에서 전문을 확인하실 수 있습니다.


